==> apimodule-1.0.5.tar.gz: lib/msimpersaa/response/kursus_response.dart <==
class KursusResponse {
  bool con;
  String msg;
  List<KursusResults> results;

  KursusResponse({this.con, this.msg, this.results});

  KursusResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <KursusResults>[];
      json['results'].forEach((v) {
        results.add(KursusResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class KursusResults {
  int id;
  String nip;
  String nomorPiagamSetifikat;
  String tanggalPiagamSetifikat;
  String namaKursus;
  String tempatKursus;
  String penyelenggara;
  String angkatan;
  String jenis;
  String tglMulai;
  String tglSelesai;
  String documen;
  String pathFile;

  KursusResults(
      {this.id,
      this.nip,
      this.nomorPiagamSetifikat,
      this.tanggalPiagamSetifikat,
      this.namaKursus,
      this.tempatKursus,
      this.penyelenggara,
      this.angkatan,
      this.jenis,
      this.tglMulai,
      this.tglSelesai,
      this.documen,
      this.pathFile});

  KursusResults.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    nip = json['nip'];
    nomorPiagamSetifikat = json['nomor_piagam_setifikat'];
    tanggalPiagamSetifikat = json['tanggal_piagam_setifikat'];
    namaKursus = json['nama_kursus'];
    tempatKursus = json['tempat_kursus'];
    penyelenggara = json['penyelenggara'];
    angkatan = json['angkatan'];
    jenis = json['jenis'];
    tglMulai = json['tgl_mulai'];
    tglSelesai = json['tgl_selesai'];
    documen = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['nip'] = this.nip;
    data['nomor_piagam_setifikat'] = this.nomorPiagamSetifikat;
    data['tanggal_piagam_setifikat'] = this.tanggalPiagamSetifikat;
    data['nama_kursus'] = this.namaKursus;
    data['tempat_kursus'] = this.tempatKursus;
    data['penyelenggara'] = this.penyelenggara;
    data['angkatan'] = this.angkatan;
    data['jenis'] = this.jenis;
    data['tgl_mulai'] = this.tglMulai;
    data['tgl_selesai'] = this.tglSelesai;
    data['dokumen'] = this.documen;
    data['path_file'] = this.pathFile;
    return data;
  }
}

==> apimodule-1.1.5.tar.gz: lib/msimpersaa/response/kursus_response.dart <==
class KursusResponse {
  bool con;
  String msg;
  List<KursusResults> results;

  KursusResponse({this.con, this.msg, this.results});

  KursusResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <KursusResults>[];
      json['results'].forEach((v) {
        results.add(KursusResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class KursusResults {
  int id;
  String nip;
  String nomorPiagamSetifikat;
  String tanggalPiagamSetifikat;
  String namaKursus;
  String tempatKursus;
  String penyelenggara;
  String angkatan;
  String jenis;
  String tglMulai;
  String tglSelesai;
  String document;
  String pathFile;

  KursusResults(
      {this.id,
      this.nip,
      this.nomorPiagamSetifikat,
      this.tanggalPiagamSetifikat,
      this.namaKursus,
      this.tempatKursus,
      this.penyelenggara,
      this.angkatan,
      this.jenis,
      this.tglMulai,
      this.tglSelesai,
      this.document,
      this.pathFile});

  KursusResults.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    nip = json['nip'];
    nomorPiagamSetifikat = json['nomor_piagam_setifikat'];
    tanggalPiagamSetifikat = json['tanggal_piagam_setifikat'];
    namaKursus = json['nama_kursus'];
    tempatKursus = json['tempat_kursus'];
    penyelenggara = json['penyelenggara'];
    angkatan = json['angkatan'];
    jenis = json['jenis'];
    tglMulai = json['tgl_mulai'];
    tglSelesai = json['tgl_selesai'];
    document = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['nip'] = this.nip;
    data['nomor_piagam_setifikat'] = this.nomorPiagamSetifikat;
    data['tanggal_piagam_setifikat'] = this.tanggalPiagamSetifikat;
    data['nama_kursus'] = this.namaKursus;
    data['tempat_kursus'] = this.tempatKursus;
    data['penyelenggara'] = this.penyelenggara;
    data['angkatan'] = this.angkatan;
    data['jenis'] = this.jenis;
    data['tgl_mulai'] = this.tglMulai;
    data['tgl_selesai'] = this.tglSelesai;
    data['dokumen'] = this.document;
    data['path_file'] = this.pathFile;
    return data;
  }
}
